@@ -126,7 +126,7 @@ UninitializeTouch(InputInfoPtr pInfo)
         proto_data->last_mt_vals = NULL;
     }
 
-    mtdev_close(proto_data->mtdev);
+    mtdev_close_delete(proto_data->mtdev);
     proto_data->mtdev = NULL;
     proto_data->num_touches = 0;
 }
@@ -518,13 +518,13 @@ SynapticsReadEvent(InputInfoPtr pInfo, struct input_event *ev)
     if (len <= 0) {
         /* We use X_NONE here because it doesn't alloc */
         if (errno != EAGAIN)
-            xf86MsgVerb(X_NONE, 0, "%s: Read error %s\n", pInfo->name,
-                        strerror(errno));
+            LogMessageVerbSigSafe(X_ERROR, 0, "%s: Read error %d\n", pInfo->name,
+                                  errno);
         rc = FALSE;
     }
     else if (len % sizeof(*ev)) {
-        xf86MsgVerb(X_NONE, 0, "%s: Read error, invalid number of bytes.",
-                    pInfo->name);
+        LogMessageVerbSigSafe(X_ERROR, 0, "%s: Read error, invalid number of bytes.",
+                              pInfo->name);
         rc = FALSE;
     }
     return rc;
@@ -878,7 +878,7 @@ event_query_touch(InputInfoPtr pInfo)
     }
 
  out:
-    mtdev_close(mtdev);
+    mtdev_close_delete(mtdev);
 }
 #endif
 
